@@ -144,7 +144,7 @@ def getwvTableForParent(access_token,subscription_key,rootUrl,activeOU,wellview,
 
 
 def putwvColumnByIDREC(access_token,subscription_key,rootUrl,activeOU,wellview,table,idwell,idrec,column,writeVal):
-    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/entityId/{idwell}/recordId/{idrec}/{column}"
+    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/entityId/{idwell}/recordId/{idrec}/{column}?$unitset=us"
     put_headers = {
                 "Content-Type":'application/json',
                 "Authorization":"Bearer %s" %(access_token),
@@ -154,3 +154,16 @@ def putwvColumnByIDREC(access_token,subscription_key,rootUrl,activeOU,wellview,t
     payload = json.dumps(writeVal)         
     updateColumn = r.put(url=url,headers=put_headers,data=payload)
     return updateColumn
+
+
+def postwvRowByIDWELL(access_token,subscription_key,rootUrl,activeOU,wellview,table,writeVal):
+    url = F"{rootUrl}/{activeOU}/wellview/data/{table}"
+    post_headers = {
+                "Content-Type":'application/json',
+                "Authorization":"Bearer %s" %(access_token),
+                "Ocp-Apim-Subscription-Key":subscription_key,
+                "wellview":wellview
+                }
+    payload = json.dumps(writeVal)         
+    insertRow = r.post(url=url,headers=post_headers,data=payload)
+    return insertRow
